"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Configuration = void 0;
const events_1 = require("events");
const fs_1 = require("fs");
const utils_1 = require("./utils");
class Configuration extends events_1.EventEmitter {
    constructor(configResolver) {
        super();
        this.configResolver = configResolver;
        this._data = {};
    }
    load() {
        try {
            this._data = this.configResolver.resolveConfig();
            this.emit('loaded', this._data.self_path);
        }
        catch (err) {
            this.emit('error', err.message);
        }
    }
    set(path, value) {
        return (0, utils_1.set)(this._data, path, value);
    }
    get(path) {
        const envPath = path.toUpperCase().split('.').join('_');
        const value = (0, utils_1.get)(process.env, envPath);
        if (value) {
            this.emit('info', `Configuration value for ${envPath} overridden by environment.`);
            return value;
        }
        return (0, utils_1.get)(this._data, path);
    }
    save() {
        const path = this._data.self_path;
        try {
            (0, fs_1.writeFileSync)(path, JSON.stringify(this._data, null, 2));
            this.emit('saved', this._data.self_path);
        }
        catch (err) {
            this.emit('error', err.message);
        }
    }
}
exports.Configuration = Configuration;
//# sourceMappingURL=Configuration.js.map